@@ -1,5 +1,7 @@
+mod error_code;
 mod primitives;
 mod structs;
 
+pub use error_code::*;
 pub use primitives::*;
 pub use structs::*;
